@@ -1,14 +1,18 @@
 #' @title Generic print function for eventlog
 #' @description Generic print function for eventlog
-#' @param x Eventlog object
+#' @param x \code{\link{log}}: Object of class \code{\link{eventlog}} or \code{\link{activitylog}}.
 #' @param ... Additional Arguments
+#' @importFrom pillar style_subtle
+#' @importFrom purrr map_chr
 #' @export
 
+print.log <- function(x, ...) {
+
+        if(nrow(x) > 0) {
 
-print.eventlog <- function(x, ...) {
        nev <- n_events(x)
 
-        cat("Log of", nev, ngettext(nev, "event", "events"), "consisting of:\n")
+        cat(map_chr(c("# Log of", nev, ngettext(nev, "event", "events"), "consisting of:\n"), style_subtle))
         if(nev < 250000) {
                 ntr <- n_traces(x)
                 cat(ntr, ngettext(ntr, "trace", "traces"), "\n")
@@ -23,22 +27,33 @@ print.eventlog <- function(x, ...) {
         )
         nrs <- n_resources(x)
         cat(nrs, ngettext(nrs, "resource", "resources"), "\n")
-        timestamps <- x[[timestamp(x)]]
+
+        if("activitylog" %in% class(x)) {
+        	timestamps <- gather(x[timestamps(x)]) %>% pull(.data[["value"]])
+        } else {
+        	timestamps <- x[[timestamp(x)]]
+
+        }
+
         cat(
                 "Events occurred from", format(min(timestamps)),
                 "until", format(max(timestamps)), "\n", "\n"
         )
-        cat("Variables were mapped as follows:\n")
+        cat(style_subtle("# Variables were mapped as follows:\n"))
         print(mapping(x))
         cat("\n")
-	NextMethod(x)
+
+        } else {
+                cat("EMPTY EVENT LOG\n")
+        }
+        NextMethod(x)
 }
 
 #' @export
-print.grouped_eventlog <- function(x, ...) {
+print.grouped_log <- function(x, ...) {
 	groups <- groups(x)
 	x <- ungroup_eventlog(x)
-	cat(glue("# Groups: [{paste(groups, collapse = \", \")}]"))
+	cat(style_subtle(glue("# Groups: [{paste(groups, collapse = \", \")}]")))
 	cat("\nGrouped ")
 	print(x)
 }
